@@ -39,13 +39,19 @@
 /************************************************************
  * Common helper used within the lib and as an API
  ************************************************************/
-DSO_PUBLIC
-void kcapi_memset_secure(void *s, int c, size_t n)
+IMPL_SYMVER(memset_secure, "1.3.1")
+void impl_memset_secure(void *s, int c, size_t n)
 {
 	memset(s, c, n);
 	__asm__ __volatile__("" : : "r" (s) : "memory");
 }
 
+ORIG_SYMVER(memset_secure, "0.12.0")
+void orig_memset_secure(void *s, int c, uint32_t n)
+{
+        impl_memset_secure(s, c, n);
+}
+
 /************************************************************
  * Logging logic
  ************************************************************/
@@ -125,7 +131,7 @@ ssize_t _kcapi_common_send_meta(struct kcapi_handle *handle,
 
 	/* plaintext / ciphertext data */
 	struct cmsghdr *header = NULL;
-	size_t *type = NULL;
+	uint32_t *type = NULL;
 	struct msghdr msg;
 
 	/* IV data */
@@ -135,7 +141,7 @@ ssize_t _kcapi_common_send_meta(struct kcapi_handle *handle,
 			  0;
 
 	/* AEAD data */
-	size_t *assoclen = NULL;
+	uint32_t *assoclen = NULL;
 	size_t assoc_msg_size = handle->aead.assoclen ?
 				CMSG_SPACE(sizeof(*assoclen)) : 0;
 
@@ -205,7 +211,7 @@ ssize_t _kcapi_common_send_meta(struct kcapi_handle *handle,
 		header->cmsg_type = ALG_SET_AEAD_ASSOCLEN;
 		header->cmsg_len = CMSG_LEN(sizeof(*assoclen));
 		assoclen = (void*)CMSG_DATA(header);
-		*assoclen = handle->aead.assoclen;
+		*assoclen = (uint32_t)handle->aead.assoclen;
 	}
 
 	ret = sendmsg(*_kcapi_get_opfd(handle), &msg, (int)flags);
